@@ -6,7 +6,7 @@ use test_files::TestFiles;
 
 graphql_schema! {
     type Thing {
-        name: String @confql(arrayFilename: true)
+        name: String @confql(arrayIdentifier: true)
         size: Float!
     }
 
